@@ -46,23 +46,35 @@ def config_from_dir(c, name, directory, secret=False):
     return _kubectl(c, command)
 
 
+def _fuzzy_find_pod(c, podname):
+    pods = _kubectl(c, "get pods", hide="out")
+    podnames = [re.split(" +", l)[0] for l in pods.stdout.splitlines()[1:]]
+    if podname not in podnames:
+        aux = [p for p in podnames if podname in p]
+        if aux and len(aux) == 1:
+            podname = aux[0]
+        else:
+            podnames = ",".join(podnames)
+            raise Failure(f"{podname} not found in pods: {podnames}!")
+    return podname
+
+
 @task
 def logs(c, podname, zfuzzy=False, follow=False, tail=None):
     if zfuzzy:
-        pods = _kubectl(c, "get pods", hide="out")
-        podnames = [re.split(" +", l)[0] for l in pods.stdout.splitlines()[1:]]
-        if podname not in podnames:
-            aux = [p for p in podnames if podname in p]
-            if aux and len(aux) == 1:
-                podname = aux[0]
-            else:
-                podnames = ",".join(podnames)
-                raise Failure(f"{podname} not found in pods: {podnames}!")
+        podname = _fuzzy_find_pod(c, podname)
     follow = "--follow" if follow else ""
     tail = f"--tail {tail}" if tail else ""
     return _kubectl(c, f"logs {podname} {follow} {tail}")
 
 
+@task
+def kshell(c, podname, zfuzzy=False, shell="sh"):
+    if zfuzzy:
+        podname = _fuzzy_find_pod(c, podname)
+    return _kubectl(c, f"exec -it {podname} -- {shell}", pty=True)
+
+
 @task
 def kget(c, resource="pods", grep=None, status=None, keep_header=True):
     if grep:
